@@ -18,9 +18,19 @@ from pathlib import Path
 
 import luigi
 
+import luigi_tools
+
 
 class OptionalParameterTypeWarning(UserWarning):
-    """Warning class for OptionalParameter with wrong type."""
+    """Warning class for OptionalParameter with wrong type.
+
+    .. moved_to_luigi::
+        :previous_luigi_version: 3.0.3
+    """
+
+
+class UnconsumedParameterWarning(UserWarning):
+    """Warning class for parameters that are not consumed by the task."""
 
 
 class ExtParameter(luigi.Parameter):
@@ -91,6 +101,12 @@ class PathParameter(luigi.Parameter):
         absolute (bool): the given path is converted to an absolute path.
         create (bool): a folder is automatically created to the given path.
         exists (bool): raise a :class:`ValueError` if the path does not exist.
+
+    .. moved_to_luigi::
+        :previous_luigi_version: 3.0.3
+
+        The moved version dropped the ``create`` parameter as it was confusing for users that may
+        use it instead of using a target.
     """
 
     def __init__(self, *args, absolute=False, create=False, exists=False, **kwargs):
@@ -100,6 +116,8 @@ class PathParameter(luigi.Parameter):
         self.create = create
         self.exists = exists
 
+        luigi_tools.moved_to_luigi_warning(previous_luigi_version="3.0.3")
+
     def normalize(self, x):
         """Normalize the given value to a :class:`pathlib.Path` object."""
         path = Path(x)
@@ -113,10 +131,19 @@ class PathParameter(luigi.Parameter):
 
 
 class OptionalParameter:
-    """Mixin to make a parameter class optional."""
+    """Mixin to make a parameter class optional.
+
+    .. moved_to_luigi::
+        :previous_luigi_version: 3.0.3
+    """
 
     expected_type = type(None)
 
+    def __init__(self, *args, **kwargs):
+        super().__init__(*args, **kwargs)
+
+        luigi_tools.moved_to_luigi_warning(previous_luigi_version="3.0.3")
+
     def serialize(self, x):
         """Parse the given value if the value is not None else return an empty string."""
         if x is None:
@@ -141,76 +168,125 @@ class OptionalParameter:
 
     def _warn_on_wrong_param_type(self, param_name, param_value):
         if not isinstance(param_value, self.expected_type) and param_value is not None:
+            try:
+                # pylint: disable=not-an-iterable
+                param_type = f"any type in {[i.__name__ for i in self.expected_type]}"
+            except TypeError:
+                param_type = f"type '{self.expected_type.__name__}'"
             warnings.warn(
                 (
-                    f'{self.__class__.__name__} "{param_name}" with value '
-                    f'"{param_value}" is not of type {self.expected_type.__name__} or None.'
+                    f"{self.__class__.__name__} '{param_name}' with value "
+                    f"'{param_value}' is not of {param_type} or None."
                 ),
                 OptionalParameterTypeWarning,
             )
 
 
 class OptionalStrParameter(OptionalParameter, luigi.Parameter):
-    """Class to parse optional str parameters."""
+    """Class to parse optional str parameters.
+
+    .. moved_to_luigi::
+        :previous_luigi_version: 3.0.3
+    """
 
     expected_type = str
 
 
 class OptionalBoolParameter(OptionalParameter, BoolParameter):
-    """Class to parse optional bool parameters."""
+    """Class to parse optional bool parameters.
+
+    .. moved_to_luigi::
+        :previous_luigi_version: 3.0.3
+    """
 
     expected_type = bool
 
 
 class OptionalIntParameter(OptionalParameter, luigi.IntParameter):
-    """Class to parse optional int parameters."""
+    """Class to parse optional int parameters.
+
+    .. moved_to_luigi::
+        :previous_luigi_version: 3.0.3
+    """
 
     expected_type = int
 
 
 class OptionalFloatParameter(OptionalParameter, luigi.FloatParameter):
-    """Class to parse optional float parameters."""
+    """Class to parse optional float parameters.
+
+    .. moved_to_luigi::
+        :previous_luigi_version: 3.0.3
+    """
 
     expected_type = float
 
 
 class OptionalNumericalParameter(OptionalParameter, luigi.NumericalParameter):
-    """Class to parse optional numerical parameters."""
+    """Class to parse optional numerical parameters.
+
+    .. moved_to_luigi::
+        :previous_luigi_version: 3.0.3
+    """
 
     expected_type = float
 
 
 class OptionalRatioParameter(OptionalParameter, RatioParameter):
-    """Class to parse optional ratio parameters."""
+    """Class to parse optional ratio parameters.
+
+    .. moved_to_luigi::
+        :previous_luigi_version: 3.0.3
+    """
 
     expected_type = float
 
 
 class OptionalChoiceParameter(OptionalParameter, luigi.ChoiceParameter):
-    """Class to parse optional choice parameters."""
+    """Class to parse optional choice parameters.
+
+    .. moved_to_luigi::
+        :previous_luigi_version: 3.0.3
+    """
 
     expected_type = str
 
 
 class OptionalListParameter(OptionalParameter, luigi.ListParameter):
-    """Class to parse optional list parameters."""
+    """Class to parse optional list parameters.
+
+    .. moved_to_luigi::
+        :previous_luigi_version: 3.0.3
+    """
 
     expected_type = tuple
 
 
 class OptionalDictParameter(OptionalParameter, luigi.DictParameter):
-    """Class to parse optional dict parameters."""
+    """Class to parse optional dict parameters.
+
+    .. moved_to_luigi::
+        :previous_luigi_version: 3.0.3
+    """
 
     expected_type = luigi.freezing.FrozenOrderedDict
 
 
 class OptionalTupleParameter(OptionalParameter, luigi.TupleParameter):
-    """Class to parse optional tuple parameters."""
+    """Class to parse optional tuple parameters.
+
+    .. moved_to_luigi::
+        :previous_luigi_version: 3.0.3
+    """
 
     expected_type = tuple
 
 
 class OptionalPathParameter(OptionalParameter, PathParameter):
-    """Class to parse optional path parameters."""
+    """Class to parse optional path parameters.
 
-    expected_type = str
+    .. moved_to_luigi::
+        :previous_luigi_version: 3.0.3
+    """
+
+    expected_type = (str, Path)
