@@ -16,12 +16,12 @@
 import warnings
 
 import luigi
-import pytest
 import mock
+import pytest
 
 import luigi_tools.parameter
-import luigi_tools.task
 import luigi_tools.target
+import luigi_tools.task
 import luigi_tools.util
 from luigi_tools.util import set_luigi_config
 
@@ -350,9 +350,58 @@ class TestOptionalParameter:
             assert len(w) == 1
             assert issubclass(w[0].category, luigi_tools.parameter.OptionalParameterTypeWarning)
             assert str(w[0].message) == (
-                'OptionalIntParameter "a" with value "zz" is not of type int or None.'
+                "OptionalIntParameter 'a' with value 'zz' is not of type 'int' or None."
             )
 
+    def test_warning(current_test):
+        class TestOptionalFloatParameterSingleType(
+            luigi_tools.parameter.OptionalParameter, luigi.FloatParameter
+        ):
+            """Class to parse optional float parameters."""
+
+            expected_type = float
+
+        class TestOptionalFloatParameterMultiTypes(
+            luigi_tools.parameter.OptionalParameter, luigi.FloatParameter
+        ):
+            """Class to parse optional float parameters."""
+
+            expected_type = (int, float)
+
+        class TestConfig(luigi.Config):
+            param_single = TestOptionalFloatParameterSingleType()
+            param_multi = TestOptionalFloatParameterMultiTypes()
+
+        with warnings.catch_warnings(record=True) as record:
+            TestConfig(param_single=0.0, param_multi=1.0)
+
+        assert len(record) == 0
+
+        with warnings.catch_warnings(record=True) as record:
+            warnings.filterwarnings(
+                action="ignore",
+                category=Warning,
+            )
+            warnings.simplefilter(
+                action="always",
+                category=luigi_tools.parameter.OptionalParameterTypeWarning,
+            )
+            assert luigi.build(
+                [TestConfig(param_single="0", param_multi="1")], local_scheduler=True
+            )
+
+        assert len(record) == 2
+        assert issubclass(record[0].category, luigi_tools.parameter.OptionalParameterTypeWarning)
+        assert issubclass(record[1].category, luigi_tools.parameter.OptionalParameterTypeWarning)
+        assert str(record[0].message) == (
+            """TestOptionalFloatParameterSingleType 'param_single' with value '0' is not of type """
+            """'float' or None."""
+        )
+        assert str(record[1].message) == (
+            """TestOptionalFloatParameterMultiTypes 'param_multi' with value '1' is not of any """
+            """type in ['int', 'float'] or None."""
+        )
+
     def actual_test(current_test, cls, default, expected_value, expected_type, bad_data, **kwargs):
         class TestConfig(luigi.Config):
             param = cls(default=default, **kwargs)
@@ -382,7 +431,7 @@ class TestOptionalParameter:
                 else:
                     assert warnings.warn.call_count == 1
                     warnings.warn.assert_called_with(
-                        '{} "param" with value "{}" is not of type {} or None.'.format(
+                        "{} 'param' with value '{}' is not of type '{}' or None.".format(
                             cls.__name__, bad_data, expected_type
                         ),
                         luigi_tools.parameter.OptionalParameterTypeWarning,
@@ -394,7 +443,11 @@ class TestOptionalParameter:
     def test_optional_str_parameter(self, tmp_working_dir):
         with set_luigi_config({"TestConfig": {"param": "expected value", "empty_param": ""}}):
             self.actual_test(
-                luigi_tools.parameter.OptionalStrParameter, None, "expected value", "str", 0
+                luigi_tools.parameter.OptionalStrParameter,
+                None,
+                "expected value",
+                "str",
+                0,
             )
             self.actual_test(
                 luigi_tools.parameter.OptionalStrParameter,
@@ -414,19 +467,35 @@ class TestOptionalParameter:
     def test_optional_bool_parameter(self, tmp_working_dir):
         with set_luigi_config({"TestConfig": {"param": "true", "empty_param": ""}}):
             self.actual_test(
-                luigi_tools.parameter.OptionalBoolParameter, None, True, "bool", "bad data"
+                luigi_tools.parameter.OptionalBoolParameter,
+                None,
+                True,
+                "bool",
+                "bad data",
             )
             self.actual_test(
-                luigi_tools.parameter.OptionalBoolParameter, False, True, "bool", "bad data"
+                luigi_tools.parameter.OptionalBoolParameter,
+                False,
+                True,
+                "bool",
+                "bad data",
             )
 
     def test_optional_float_parameter(self, tmp_working_dir):
         with set_luigi_config({"TestConfig": {"param": "10.5", "empty_param": ""}}):
             self.actual_test(
-                luigi_tools.parameter.OptionalFloatParameter, None, 10.5, "float", "bad data"
+                luigi_tools.parameter.OptionalFloatParameter,
+                None,
+                10.5,
+                "float",
+                "bad data",
             )
             self.actual_test(
-                luigi_tools.parameter.OptionalFloatParameter, 1.5, 10.5, "float", "bad data"
+                luigi_tools.parameter.OptionalFloatParameter,
+                1.5,
+                10.5,
+                "float",
+                "bad data",
             )
 
     def test_optional_dict_parameter(self, tmp_working_dir):
@@ -449,19 +518,35 @@ class TestOptionalParameter:
     def test_optional_list_parameter(self, tmp_working_dir):
         with set_luigi_config({"TestConfig": {"param": "[10.5]", "empty_param": ""}}):
             self.actual_test(
-                luigi_tools.parameter.OptionalListParameter, None, (10.5,), "tuple", "bad data"
+                luigi_tools.parameter.OptionalListParameter,
+                None,
+                (10.5,),
+                "tuple",
+                "bad data",
             )
             self.actual_test(
-                luigi_tools.parameter.OptionalListParameter, (1.5,), (10.5,), "tuple", "bad data"
+                luigi_tools.parameter.OptionalListParameter,
+                (1.5,),
+                (10.5,),
+                "tuple",
+                "bad data",
             )
 
     def test_optional_tuple_parameter(self, tmp_working_dir):
         with set_luigi_config({"TestConfig": {"param": "[10.5]", "empty_param": ""}}):
             self.actual_test(
-                luigi_tools.parameter.OptionalTupleParameter, None, (10.5,), "tuple", "bad data"
+                luigi_tools.parameter.OptionalTupleParameter,
+                None,
+                (10.5,),
+                "tuple",
+                "bad data",
             )
             self.actual_test(
-                luigi_tools.parameter.OptionalTupleParameter, (1.5,), (10.5,), "tuple", "bad data"
+                luigi_tools.parameter.OptionalTupleParameter,
+                (1.5,),
+                (10.5,),
+                "tuple",
+                "bad data",
             )
 
     def test_optional_numerical_parameter(self, tmp_working_dir):
