@@ -15,14 +15,15 @@
 """Tests for luigi-tools tasks."""
 import json
 import logging
+import warnings
 
 import luigi
 import pytest
 from luigi.util import inherits
 
 import luigi_tools.parameter
-import luigi_tools.task
 import luigi_tools.target
+import luigi_tools.task
 import luigi_tools.util
 from luigi_tools.task import DuplicatedParameterError
 from luigi_tools.task import GlobalParameterNoValueError
@@ -159,7 +160,13 @@ class TestCopyParams:
             assert luigi.build([TaskCopyListDictParams()], local_scheduler=True)
 
     def type_test(
-        self, cls_param, initial_value, str_initial_value, new_value, str_new_value, **kwargs
+        self,
+        cls_param,
+        initial_value,
+        str_initial_value,
+        new_value,
+        str_new_value,
+        **kwargs,
     ):
 
         # Test with parameters that are serialized to generate the task ID
@@ -208,7 +215,8 @@ class TestCopyParams:
             }
         ):
             assert luigi.build(
-                [TaskWithTypeParams(), TaskCopyTypeParams(with_value=True)], local_scheduler=True
+                [TaskWithTypeParams(), TaskCopyTypeParams(with_value=True)],
+                local_scheduler=True,
             )
 
         with set_luigi_config(
@@ -222,7 +230,8 @@ class TestCopyParams:
             }
         ):
             assert luigi.build(
-                [TaskWithTypeParams(), TaskCopyTypeParams(with_value=False)], local_scheduler=True
+                [TaskWithTypeParams(), TaskCopyTypeParams(with_value=False)],
+                local_scheduler=True,
             )
         print("test end with", cls_param)
 
@@ -237,7 +246,11 @@ class TestCopyParams:
 
     def test_optional_list_param(self, tmp_working_dir):
         self.type_test(
-            luigi_tools.parameter.OptionalListParameter, (1, 2), "[1, 2]", (10, 20), "[10, 20]"
+            luigi_tools.parameter.OptionalListParameter,
+            (1, 2),
+            "[1, 2]",
+            (10, 20),
+            "[10, 20]",
         )
 
 
@@ -526,7 +539,10 @@ class TestCopyParamsWithGlobals:
             }
         ):
             assert luigi.build(
-                [GlobalParamTaskWithListDictParams(), GlobalParamTaskCopyListDictParams()],
+                [
+                    GlobalParamTaskWithListDictParams(),
+                    GlobalParamTaskCopyListDictParams(),
+                ],
                 local_scheduler=True,
             )
 
@@ -809,7 +825,11 @@ class TestLogTargetMixin:
         assert res == []
 
     def test_output_logger_and_global_param(self, tmpdir, caplog):
-        class TaskE(luigi_tools.task.LogTargetMixin, luigi_tools.task.GlobalParamMixin, luigi.Task):
+        class TaskE(
+            luigi_tools.task.LogTargetMixin,
+            luigi_tools.task.GlobalParamMixin,
+            luigi.Task,
+        ):
             """"""
 
             e = luigi.Parameter(default="e")
@@ -826,8 +846,12 @@ class TestLogTargetMixin:
         assert luigi.build([TaskE()], local_scheduler=True)
         res = [i for i in caplog.record_tuples if i[0] == "luigi_tools.task"]
         assert res == [
-            ("luigi_tools.task", 10, "Attributes of TaskE task after global processing:"),
-            ("luigi_tools.task", 10, "Atribute: e == e"),
+            (
+                "luigi_tools.task",
+                10,
+                "Attributes of TaskE task after global processing:",
+            ),
+            ("luigi_tools.task", 10, "Attribute: e == e"),
             ("luigi_tools.task", 10, f"Output of TaskE task: {tmpdir / 'test_e'}"),
         ]
 
@@ -877,3 +901,70 @@ def test_remove_corrupted_output(tmpdir, caplog):
     with open(tmpdir / "matrix.dat", "r") as f_handle:
         matrix_values = f_handle.read().splitlines()
         assert len(matrix_values) == 6
+
+
+class TestCheckUnconsumedParamsMixin:
+    def test_unconsumed(self, tmpdir, caplog):
+        class TaskA(luigi_tools.task.WorkflowTask):
+            """"""
+
+            a = luigi.Parameter(default="a")
+
+            def run(self):
+                create_not_empty_file(self.output().path)
+
+            def output(self):
+                return luigi.LocalTarget(tmpdir / f"test_TaskA_{self.a}")
+
+        class TaskB(luigi_tools.task.WorkflowTask):
+            """"""
+
+            a = luigi.Parameter(default="a")
+
+            def run(self):
+                create_not_empty_file(self.output().path)
+
+            def output(self):
+                return luigi.LocalTarget(tmpdir / f"test_TaskB_{self.a}")
+
+        with set_luigi_config(
+            {
+                "TaskA": {
+                    "a": "a",
+                    "b": "b",
+                    "c": "c",
+                },
+                "TaskB": {
+                    "a": "a",
+                    "b": "b",
+                    "c": "c",
+                },
+            }
+        ):
+            with warnings.catch_warnings(record=True) as w:
+                warnings.filterwarnings(
+                    action="ignore",
+                    category=Warning,
+                )
+                warnings.simplefilter(
+                    action="always",
+                    category=luigi_tools.parameter.UnconsumedParameterWarning,
+                )
+                assert luigi.build([TaskA(), TaskB()], local_scheduler=True)
+
+                assert len(w) == 4
+                expected = [
+                    ("b", "TaskA"),
+                    ("c", "TaskA"),
+                    ("b", "TaskB"),
+                    ("c", "TaskB"),
+                ]
+                for i, (expected_value, task_name) in zip(w, expected):
+                    assert issubclass(i.category, luigi_tools.parameter.UnconsumedParameterWarning)
+                    assert str(i.message) == (
+                        "The configuration contains the parameter "
+                        f"'{expected_value}' with value '{expected_value}' that is not consumed by "
+                        f"the task '{task_name}'."
+                    )
+
+        assert all([check_not_empty_file(i.path) for i in luigi.task.flatten(TaskA().output())])
