@@ -21,14 +21,14 @@ import luigi
 import pytest
 from luigi.parameter import _no_value as PARAM_NO_VALUE
 
-import luigi_tools.task
+import luigi_tools
 import luigi_tools.target
+import luigi_tools.task
 import luigi_tools.util
 from luigi_tools.util import set_luigi_config
 
 from .tools import create_not_empty_file
 
-
 DATA = Path(__file__).parent / "data"
 
 
@@ -120,17 +120,17 @@ def test_dependency_graph(tmpdir, task_collection):
     # Test graphviz_dependency_graph()
     dot = luigi_tools.util.graphviz_dependency_graph(graph)
     assert dot.body == [
-        "\tTaskE [color=red penwidth=1.5]",
-        "\tTaskD",
-        "\tTaskE -> TaskD",
-        "\tTaskB",
-        "\tTaskD -> TaskB",
-        "\tTaskA",
-        "\tTaskB -> TaskA",
-        "\tTaskC",
-        "\tTaskD -> TaskC",
-        "\tTaskA",
-        "\tTaskC -> TaskA",
+        "\tTaskE [color=red penwidth=1.5]\n",
+        "\tTaskD\n",
+        "\tTaskE -> TaskD\n",
+        "\tTaskB\n",
+        "\tTaskD -> TaskB\n",
+        "\tTaskA\n",
+        "\tTaskB -> TaskA\n",
+        "\tTaskC\n",
+        "\tTaskD -> TaskC\n",
+        "\tTaskA\n",
+        "\tTaskC -> TaskA\n",
     ]
     assert dot.node_attr == {
         "shape": "box",
@@ -157,17 +157,17 @@ def test_dependency_graph(tmpdir, task_collection):
         edge_kwargs={(task_collection.TaskB(), task_collection.TaskA()): {"label": "custom label"}},
     )
     assert dot_with_attrs.body == [
-        "\tTaskE [color=blue penwidth=1.5]",
-        "\tcustom_name",
-        "\tTaskE -> custom_name",
-        "\tTaskB",
-        "\tcustom_name -> TaskB",
-        '\tTaskA [custom_attr="custom value"]',
-        '\tTaskB -> TaskA [label="custom label"]',
-        "\tTaskC",
-        "\tcustom_name -> TaskC",
-        '\tTaskA [custom_attr="custom value"]',
-        "\tTaskC -> TaskA",
+        "\tTaskE [color=blue penwidth=1.5]\n",
+        "\tcustom_name\n",
+        "\tTaskE -> custom_name\n",
+        "\tTaskB\n",
+        "\tcustom_name -> TaskB\n",
+        '\tTaskA [custom_attr="custom value"]\n',
+        '\tTaskB -> TaskA [label="custom label"]\n',
+        "\tTaskC\n",
+        "\tcustom_name -> TaskC\n",
+        '\tTaskA [custom_attr="custom value"]\n',
+        "\tTaskC -> TaskA\n",
     ]
     assert dot_with_attrs.node_attr == {
         "shape": "box",
@@ -177,7 +177,10 @@ def test_dependency_graph(tmpdir, task_collection):
         "style": "setlinewidth(0.5),filled",
         "fillcolor": "white",
     }
-    assert dot_with_attrs.edge_attr == {"arrowsize": "0.75", "style": "setlinewidth(0.5)"}
+    assert dot_with_attrs.edge_attr == {
+        "arrowsize": "0.75",
+        "style": "setlinewidth(0.5)",
+    }
 
     # Test graphviz_dependency_graph() with empty graph
     with pytest.raises(ValueError):
@@ -424,3 +427,57 @@ class TestSetLuigiConfig:
         config.read_dict(params)
         with set_luigi_config(config):
             assert luigi.build([Task(expected_a="a_from_cfg")], local_scheduler=True)
+
+
+def test_deprecation_warning():
+    with pytest.warns(
+        luigi_tools.MovedToLuigiWarning,
+        match="This feature was moved to the luigi package and is available since version 1.2.3.",
+    ):
+        luigi_tools.moved_to_luigi_warning("1.2.3")
+
+    with pytest.warns(
+        luigi_tools.MovedToLuigiWarning,
+        match=(
+            "This feature was moved to the luigi package and is available since version 1.2.3. It "
+            "will be deprecated in version 3.4.5."
+        ),
+    ):
+        luigi_tools.moved_to_luigi_warning("1.2.3", deprecation_version="3.4.5")
+
+    with pytest.warns(
+        luigi_tools.MovedToLuigiWarning,
+        match=(
+            "This feature was moved to the luigi package and will be available after version 1.2.3."
+        ),
+    ):
+        luigi_tools.moved_to_luigi_warning(previous_luigi_version="1.2.3")
+
+    with pytest.warns(
+        luigi_tools.MovedToLuigiWarning,
+        match=(
+            "This feature was moved to the luigi package and will be available after version 1.2.3."
+            " It will be deprecated in version 3.4.5."
+        ),
+    ):
+        luigi_tools.moved_to_luigi_warning(
+            previous_luigi_version="1.2.3", deprecation_version="3.4.5"
+        )
+
+    with pytest.raises(
+        ValueError,
+        match=(
+            "Either the 'luigi_version' or the 'previous_luigi_version' argument must be not None "
+            "but not both of them"
+        ),
+    ):
+        luigi_tools.moved_to_luigi_warning()
+
+    with pytest.raises(
+        ValueError,
+        match=(
+            "Either the 'luigi_version' or the 'previous_luigi_version' argument must be not None "
+            "but not both of them"
+        ),
+    ):
+        luigi_tools.moved_to_luigi_warning("1.2.3", "3.4.5")
